import { useLocation, useNavigate } from "react-router-dom"
import { useGlobalStore } from '@/store/global';
import { lazy, useEffect, useState } from 'react';
import GloablLoading from '@/components/global-loading';
import Slide from './slide';
import Header from './header';
import { useUserStore } from '@/store/global/user';
import { useMenusStore } from "@/store/global/menu";
import { Menu } from '@/models';
import { components } from '@/router/config';

import { replaceRoutes, router } from '@/router/router';
import Result404 from './404';

import './index.css'
import TabsLayout from './tabs-layout';
import Content from './content';
import homeService from '@/request/service/home';
import { useRequest } from "@/hooks/use-request";
import menuData from '../../mock/menu.json'

const BasicLayout: React.FC = () => {

  const [loading, setLoading] = useState(true);

  const { lang } = useGlobalStore();
  const { currentUser } = useUserStore();
  const { setMenus } = useMenusStore();
  const navigate = useNavigate();
  const location = useLocation();
  // const { setLatestMessage } = useMessageStore();

  const { runAsync: getAnnouncement } = useRequest(homeService.getAnnouncement, { manual: true });

  const formatMenus = (
    menus: Menu[],
    menuGroup: Record<string, Menu[]>,
    routes: Menu[],
    parentMenu?: Menu
  ): Menu[] => {
    return menus.map(menu => {
      const children = menuGroup[menu.id];

      const parentPaths = parentMenu?.parentPaths || [];
      const path = (parentMenu ? `${parentPaths.at(-1)}${menu.path}` : menu.path) || '';

      routes.push({ ...menu, path, parentPaths });

      return {
        ...menu,
        path,
        parentPaths,
        children: children?.length ? formatMenus(children, menuGroup, routes, {
          ...menu,
          parentPaths: [...parentPaths, path || ''].filter(o => o),
        }) : undefined,
      };
    });
  }

  useEffect(() => {
    const menus:Array<Menu> = menuData as Array<Menu> ;
    console.log(menus);

    const menuGroup = menus.reduce<Record<string, Menu[]>>((prev, menu) => {
      if (!menu.parentId) {
        return prev;
      }

      if (!prev[menu.parentId]) {
        prev[menu.parentId] = [];
      }

      prev[menu.parentId].push(menu);
      return prev;
    }, {});


    const routes: Menu[] = [];

    const formatedMenus = formatMenus(menus.filter(o => !o.parentId), menuGroup, routes);
    setMenus(formatedMenus);
    console.log(components, 'components');
    replaceRoutes('*', [
      ...routes.map(menu => ({
        path: `/*${menu.path}`,
        Component: menu.component ? lazy(components[menu.component]) : null,
        id: `/*${menu.path}`,
        handle: {
          parentPaths: menu.parentPaths,
          path: menu.path,
          name: menu.name,
          icon: menu.icon,
        },
      })), {
        id: '*',
        path: '*',
        Component: Result404,
        handle: {
          path: '404',
          name: '404',
        },
      }
    ]);

    setLoading(false);

    // replace一下当前路由，为了触发路由匹配
    router.navigate(`${location.pathname}${location.search}`, { replace: true });
  }, [ currentUser ]);

  useEffect(() => {
    function storageChange(e: StorageEvent) {
      if (e.key === useGlobalStore.persist.getOptions().name) {
        useGlobalStore.persist.rehydrate();
      }
    }

    window.addEventListener<'storage'>('storage', storageChange);

    return () => {
      window.removeEventListener<'storage'>('storage', storageChange);
    }
  }, []);

  if (loading) {
    return (
      <GloablLoading />
    )
  }

  return (
    <div>
      <div key={lang} className='bg-primary overflow-hidden'>
        <Header />
        <Slide />
        <Content>
          <TabsLayout />
        </Content>
      </div>
    </div>
  );
};

export default BasicLayout;
