import { Space, Tag, Table, Form, Row, Col, Input, InputNumber, Button, Avatar, Divider } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { t } from '@/utils/i18n';
import { IconBuguang } from '@/assets/icons/buguang';
import React, { useState } from 'react';
import type { TableRowSelection } from 'antd/es/table/interface';
import mData from '../../../../../mock/findMaterialPage.json'


// {
//   "id": 1465,
//   "createTime": "2023-06-06 10:47:21",
//   "classifyId": 52,
//   "materialImgId": 1875217,
//   "materialName": "HDC-11010015-P",
//   "materialRemark": "multiple boys, brown hair, striped, hat, baseball cap, dark skin, backpack, jacket, dark-skinned male, pink dress, bag, white background, headband, camera, pants, shirt, striped shirt, backwards hat, dress, 1girl, parody, bandana, black hair, simple background, vest, holding, english text, 3boys, standing, blue jacket, white skin, short hair, shoes",
//   "materialWidth": 885.0000,
//   "materialHeight": 711.0000,
//   "materialSize": 617393,
//   "createId": 1,
//   "classify": {
//       "id": 52,
//       "classifyName": "其他"
//   },
//   "materialImgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/6/06/20230606104721A806.png"
// },

interface Classify {
  id: number;
  classifyName: string;
}

interface DataType {
  id: number;
  createTime: string;
  classifyId: number;
  materialImgId: number;
  materialName: string;
  materialRemark: string;
  materialWidth: number;
  materialHeight: number;
  materialSize: number;
  createId: number;
  materialImgUrl: string;
  dictDetails: string[];
  classify: Classify;
}

const TablePage: React.FC = () => {

  const columns: ColumnsType<DataType> = [
    {
      title: '图片',
      dataIndex: 'materialImgUrl',
      key: 'materialImgUrl',
      render: (value: string) => (
        <div className='flex justify-center'>
          {value ? (
            <img src={value} className='w-[40px] h-[40px] flex items-center rounded-[50%]' />
          ) : (
            <Avatar className='bg-[gold] align-middle flex items-center justify-center w-[40px] h-[40px]' icon={<IconBuguang />} />
          )}
        </div>
      ),
      align: 'center',
      width: 100,
    },
    {
      title: '标题',
      dataIndex: 'materialName',
      key: 'materialName',
      width: 150,
    },
    {
      title: '分类',
      dataIndex: ['classify', 'classifyName'],
      key: 'classify',
      width: 80,
    },
    {
      title:'描述',
      key: 'materialRemark',
      dataIndex: 'materialRemark'
    },
    {
      title: '分辨率',
      key: 'materialInfo',
      render:(_, record) => (
        <>
        {record.materialWidth}px * {record.materialHeight}px
        </>
      ),
      width: 150,
    },
    {
      title: '图片大小',
      dataIndex: 'materialSize',
      key: 'materialRemark',
      render:(value: number) => (
        <>
        {value}kb
        </>
      ),
      width: 100,
    },
    {
      title:'上传时间',
      key: 'createTime',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="middle" split={(
          <Divider type='vertical' />
        )}>
          <a
            onClick={() => {
              // setCreateVisible(true);
              // setCurRowData(record);
            }}>
            编辑
          </a>
          <a
            onClick={() => {
              // setEditData(record);
              // setCreateVisible(true);
            }}>
              删除
            </a>
        </Space>
      ),
      width: 150,
    },
  ];

  const data: Array<DataType> = mData as Array<DataType>;

  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    console.log('selectedRowKeys changed: ', newSelectedRowKeys);
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const rowSelection: TableRowSelection<DataType> = {
    selectedRowKeys,
    onChange: onSelectChange,
    selections: [
      Table.SELECTION_ALL,
      Table.SELECTION_INVERT,
      Table.SELECTION_NONE,
      {
        key: 'odd',
        text: 'Select Odd Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return false;
            }
            return true;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
      {
        key: 'even',
        text: 'Select Even Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return true;
            }
            return false;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
    ],
  };


  return (
    <div>
      <div className="dark:bg-[rgb(33,41,70)] rounded-md">
        <Table rowKey="id" rowSelection={rowSelection} scroll={{ x: true }} columns={columns} dataSource={data} className='bg-transparent' 
          pagination={{ position: ['bottomRight'] }}
        />
      </div>
    </div>
  );
};

export default TablePage;
