import React, { useEffect, useMemo, useState } from 'react'
import { CloseOutlined, DeleteOutlined, PlusOutlined } from '@ant-design/icons';
import { Drawer, Form, Input, Card, Space, Button, Upload, Popconfirm, Modal, FormListOperation, FormListFieldData } from 'antd'
import type { RcFile, UploadProps } from 'antd/es/upload';
import type { UploadFile } from 'antd/es/upload/interface';

const layout = {
  labelCol: { span: 4, },
  wrapperCol: { span: 16 },
  bordered: false,
};

// {
//   "id": 412,
//   "prototypeId": 89,
//   "": 1991125,
//   "maskImgId": 1991130,
//   "imgName": "3.jpg",
//   "imgType": 2,
//   "imgWidth": 600.0,
//   "imgHeight": 600.0,
//   "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A056.jpg",
//   "maskImgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114413A061.png"
// }

export interface MaskPicture {
  id: number;
  prototypeId: number;
  imgId: number;
  maskImgId?: number;
  imgName: string;
  imgType: number;
  imgWidth: number;
  imgHeight: number;
  imgUrl: string;
  maskImgUrl?: string;
}

interface MaskPictureProps {
  visible: boolean;
  onCancel: (flag?: boolean) => void;
  onSave: () => void;
  dataSource?: MaskPicture[] | null;
}

const getBase64 = (file: RcFile): Promise<string> =>
  new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    reader.onload = () => resolve(reader.result as string);
    reader.onerror = (error) => reject(error);
  });


const MaskPictureEditor: React.FC<MaskPictureProps> = (props) => {

  const { visible, onCancel, onSave, dataSource } = props;
  const [saveLoading, setSaveLoading] = useState(false);
  const [previewOpen, setPreviewOpen] = useState(false);
  const [previewImage, setPreviewImage] = useState('');
  const [previewTitle, setPreviewTitle] = useState('');
  const [form] = Form.useForm();

  useEffect(() => {
    if (visible) {
      setInitValue();
    } else {
      form.resetFields();
    }
  }, [visible]);

  async function setInitValue() {
  }

  const save = async (values: any) => {
    setSaveLoading(true);

    setSaveLoading(false);
  }

  const handleCancel = () => setPreviewOpen(false);

  const handlePreview = async (file: UploadFile) => {
    if (!file.url && !file.preview) {
      file.preview = await getBase64(file.originFileObj as RcFile);
    }

    setPreviewImage(file.url || (file.preview as string));
    setPreviewOpen(true);
    setPreviewTitle(file.name || file.url!.substring(file.url!.lastIndexOf('/') + 1));
  };

  const uploadButton = (text: string) => (
    <div>
      <PlusOutlined />
      <div style={{ marginTop: 8 }}>{text}</div>
    </div>
  );

  const handleChange: UploadProps['onChange'] = (info) => {
    debugger
  }

  const MaskPictureItem = (item: MaskPicture) => {
    const mainPicture: UploadFile[] = [{
      uid: `${item.imgId}`,
      name: item.imgUrl.split("/")[-1],
      status: 'done',
      url: item.imgUrl,
    }]
    const maskPicture: UploadFile[] = item.maskImgId ? [{
      uid: `${item.maskImgId}`,
      name: item.maskImgUrl!!.split("/")[-1],
      status: 'done',
      url: item.maskImgUrl,
    }] : []
    return (
      <div className='flex justify-start'>
        <Upload 
          listType="picture-card" 
          fileList={mainPicture} 
          maxCount={1}
          onPreview={handlePreview}
          onChange={handleChange}>
          {mainPicture.length === 0  && uploadButton("上传主图")}
        </Upload>
        <Upload 
          listType="picture-card" 
          fileList={maskPicture} 
          onPreview={handlePreview}
          maxCount={1}>
          {maskPicture.length === 0  && uploadButton("上传蒙版图")}
        </Upload>
      </div>
    )
  }

  return (
    <>
      <Drawer
        open={visible}
        title="蒙版图"

        onClose={() => { onCancel() }}
        extra={
          <Space>
            <Button type="primary" size='middle' onClick={() => { save }}>
              保存
            </Button>
          </Space>
        }
        destroyOnClose
      >
        {dataSource?.map((item) => {
          return MaskPictureItem(item)
        })}
      </Drawer>
      <Modal open={previewOpen} title={previewTitle} footer={null} onCancel={handleCancel} zIndex={2000}>
        <img alt="example" style={{ width: '100%' }} src={previewImage} />
      </Modal>
    </>
  )
}

export default MaskPictureEditor;
