import { Space, Tag, Table, Form, Row, Col, Input, InputNumber, Button, Avatar } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { t } from '@/utils/i18n';
import { IconBuguang } from '@/assets/icons/buguang';
import React, { useState } from 'react';
import type { TableRowSelection } from 'antd/es/table/interface';
import SampleAttrEditor from './components/attr-editor'
import MaskPictureEditor from './components/mask-picture-editor';
import type { SampleAttribute } from './components/attr-editor'
import type { MaskPicture } from './components/mask-picture-editor';

interface DataType {
  id: number;
  createTime: string;
  spuCode: string;
  categoryId: number;
  prototypeName: string;
  createId: number;
  categoryName: string;
  createName: string;
  oneImgUrl: string;
  dictDetails: string[];
}

const TablePage: React.FC = () => {

  const columns: ColumnsType<DataType> = [
    {
      title: '示例图',
      dataIndex: 'oneImgUrl',
      key: 'oneImgUrl',
      render: (value: string) => (
        <div className='flex justify-center'>
          {value ? (
            <img src={value} className='w-[40px] h-[40px] flex items-center rounded-[50%]' />
          ) : (
            <Avatar className='bg-[gold] align-middle flex items-center justify-center w-[40px] h-[40px]' icon={<IconBuguang />} />
          )}
        </div>
      ),
      align: 'center',
      width: 100,
    },
    {
      title: 'SPU编码',
      dataIndex: 'spuCode',
      key: 'spuCode',
    },
    {
      title: '样机名称',
      dataIndex: 'prototypeName',
      key: 'prototypeName',
    },
    {
      title: '类目',
      key: 'categoryName',
      dataIndex: 'categoryName'
    },
    {
      title: '创建人',
      dataIndex: 'createName',
      key: 'createName',
    },
    {
      title: '创建时间',
      key: 'createTime',
      dataIndex: 'createTime'
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <a onClick={() => {
            setMaskEditorVisible(true)
          }}>蒙版图 </a>
          <a
            onClick={() => {
              // setEditData(record);
              setAttrEditorVisible(true);
            }}>属性设置</a>
          <a>编辑</a>
          <a>删除</a>
        </Space>
      ),
    },
  ];

  const data: DataType[] = [
    {
      id: 77,
      createTime: "2023-07-21 15:05:59",
      spuCode: "2-35UD6O",
      categoryId: 1264,
      prototypeName: "kfc-test2",
      createId: 2,
      categoryName: "男士T恤",
      createName: "陈相荣✨",
      oneImgUrl: "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A056.jpg",
      dictDetails: []
    },
    {
      id: 76,
      createTime: "2023-07-13 17:24:25",
      spuCode: "2-47GEE7",
      categoryId: 1264,
      prototypeName: "kfc-test",
      createId: 2,
      categoryName: "男士T恤",
      createName: "陈相荣✨",
      oneImgUrl: "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A056.jpg",
      dictDetails: []
    }
  ];

  const attrData: SampleAttribute[] = [
    {
      "id": 105,
      "prototypeId": 88,
      "attrName": "Color",
      "isContainImg": 1,
      "attrVals": [
        {
          "id": 273,
          "attrId": 105,
          "valName": "Pink",
          "imgId": 1990260,
          "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821104322A047.jpg"
        },
        {
          "id": 274,
          "attrId": 105,
          "valName": "Black",
          "imgId": 1990263,
          "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821104322A050.jpg"
        }
      ]
    },
    {
      "id": 106,
      "prototypeId": 88,
      "attrName": "Size",
      "isContainImg": 2,
      "attrVals": [
        {
          "id": 275,
          "attrId": 106,
          "valName": "XL"
        },
        {
          "id": 276,
          "attrId": 106,
          "valName": "XXL"
        }
      ]
    }
  ]

  const maskPictures: MaskPicture[] = [
    {
      "id": 412,
      "prototypeId": 89,
      "imgId": 1991125,
      "maskImgId": 1991130,
      "imgName": "3.jpg",
      "imgType": 2,
      "imgWidth": 600.0,
      "imgHeight": 600.0,
      "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A056.jpg",
      "maskImgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114413A061.png"
    },
    {
      "id": 413,
      "prototypeId": 89,
      "imgId": 1991122,
      "maskImgId": 1991131,
      "imgName": "1.jpg",
      "imgType": 2,
      "imgWidth": 600.0,
      "imgHeight": 600.0,
      "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A053.jpg",
      "maskImgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114413A062.png"
    },
    {
      "id": 414,
      "prototypeId": 89,
      "imgId": 1991127,
      "imgName": "f60911abe38e82e9dd2aaa75f3292ed2.jpg",
      "imgType": 2,
      "imgWidth": 1000.0,
      "imgHeight": 1000.0,
      "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A058.jpg"
    },
    {
      "id": 415,
      "prototypeId": 89,
      "imgId": 1991123,
      "imgName": "d247c5ec0ef78f302b803c6bf00658a2.jpg",
      "imgType": 2,
      "imgWidth": 1000.0,
      "imgHeight": 1000.0,
      "imgUrl": "https://test.vogocm.com:9010/eshop/eshop_img/2023/8/21/20230821114346A054.jpg"
    }
  ]

  const [attrEditorVisible, setAttrEditorVisible] = useState(false);
  const [maskEditorVisible, setMaskEditorVisible] = useState(false);
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  const cancelHandle = () => {
    setAttrEditorVisible(false);
  };

  const saveAttributeHandle = () => {
    setAttrEditorVisible(false);
  }

  const saveMaskPictureHandle = () => {
    setMaskEditorVisible(false);
  }

  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    console.log('selectedRowKeys changed: ', newSelectedRowKeys);
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const rowSelection: TableRowSelection<DataType> = {
    selectedRowKeys,
    onChange: onSelectChange,
    selections: [
      Table.SELECTION_ALL,
      Table.SELECTION_INVERT,
      Table.SELECTION_NONE,
      {
        key: 'odd',
        text: 'Select Odd Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return false;
            }
            return true;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
      {
        key: 'even',
        text: 'Select Even Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return true;
            }
            return false;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
    ],
  };


  return (
    <div>
      <div className="dark:bg-[rgb(33,41,70)] rounded-md">
        <Table rowKey="id" rowSelection={rowSelection} scroll={{ x: true }} columns={columns} dataSource={data} className='bg-transparent'
          pagination={{ position: ['bottomRight'] }}
        />
      </div>
      <SampleAttrEditor
        onSave={saveAttributeHandle}
        onCancel={cancelHandle}
        visible={attrEditorVisible}
        curRecord={attrData}
        editData={attrData} />

      <MaskPictureEditor
        onSave={saveMaskPictureHandle}
        onCancel={()=>{ setMaskEditorVisible(false) }}
        visible={maskEditorVisible}
        dataSource={maskPictures} />
    </div>
  );
};

export default TablePage;
